==> v8.3.zip: ru_twords_ru_tw/bible/other/thief.md <==
# вор, воровать, воровство, красть, грабить, ограбленный, грабитель, разбойник, ограбление

## Определение:

Вор (устар. — тать) — это человек, который тайком присваивает деньги или имущество, принадлежащее другим людям. Слово “грабитель” означает примерно то же самое, что и вор. Однако грабитель присваивает чужое открыто, при этом, зачастую наносит физический ущерб тому, кого он грабит, или его имуществу.

* Иисус рассказал притчу о добром самарянине, позаботившемся о избитом еврее, на которого напали разбойники. Они причинили ему множество ран, отобрали у него деньги и одежду.
* В Новом Завете сатана назван “вором”, который пришёл, чтобы украсть, убить и погубить. В этом случае слово “вор” употреблено в переносном значении. План сатаны состоит в том, чтобы удержать человека от послушания Богу. Если ему удастся сделать это, сатана украдёт у людей все те благословения, которые Бог запланировал для них.
* Воры часто действуют неожиданно. Они выжидают удобный момент, подкрадываются и высматривают и стараются всё сделать незаметно, чаще всего ночью.
* Иисус сравнил внезапность Своего возвращения в мир с неожиданными действиями вора. Точно также, как вор приходит в момент, когда его не ждут, Иисус вернётся. И мало кто будет Его ждать.

(См. также: [благословлять](../kt/bless.md), [преступление](../other/criminal.md), [распять](../kt/crucify.md), [тьма](../other/darkness.md), [губитель](../other/destroyer.md), [сила](../kt/power.md), [Самария](../names/samaria.md), [Сатана](../kt/satan.md))

## Ссылки на библейский текст:

* [2 Пет. 3:10](rc://*/tn/help/2pe/03/10)
* [Лк. 12:33-34](rc://*/tn/help/luk/12/33)
* [Мк. 14:47-50](rc://*/tn/help/mrk/14/47)
* [Притч. 6:30-31](rc://*/tn/help/pro/06/30)
* [Откр. 3:3-4](rc://*/tn/help/rev/03/03)

## Данные о слове:

* Номера Стронга: H1214, H1215, H1416, H1589, H1590, H1980, H6530, H6782, H7703, G727, G1888, G2417, G2812, G3027

==> v9.2.zip: ru_twords_ru_tw/bible/other/thief.md <==
# вор, воровать, воровство, красть, грабить, ограбленный, грабитель, разбойник, ограбление

## Определение:

Вор (устар. — тать) — это человек, который тайком присваивает деньги или имущество, принадлежащее другим людям. Слово “грабитель” означает примерно то же самое, что и вор. Однако грабитель присваивает чужое открыто, при этом, зачастую наносит физический ущерб тому, кого он грабит, или его имуществу.
* Иисус рассказал притчу о добром самарянине, позаботившемся о избитом еврее, на которого напали разбойники. Они причинили ему множество ран, отобрали у него деньги и одежду.
* В Новом Завете сатана назван “вором”, который пришёл, чтобы украсть, убить и погубить. В этом случае слово “вор” употреблено в переносном значении. План сатаны состоит в том, чтобы удержать человека от послушания Богу. Если ему удастся сделать это, сатана украдёт у людей все те благословения, которые Бог запланировал для них.
* Воры часто действуют неожиданно. Они выжидают удобный момент, подкрадываются и высматривают и стараются всё сделать незаметно, чаще всего ночью.
* Иисус сравнил внезапность Своего возвращения в мир с неожиданными действиями вора. Точно также, как вор приходит в момент, когда его не ждут, Иисус вернётся. И мало кто будет Его ждать. 

(См. также: [благословлять](../kt/bless.md), [преступление](../other/criminal.md), [распять](../kt/crucify.md), [тьма](../other/darkness.md), [губитель](../other/destroyer.md), [сила](../kt/power.md), [Самария](../names/samaria.md), [Сатана](../kt/satan.md))

## Ссылки на библейский текст:

* [2 Пет. 3:10](rc://ru/tn/help/2pe/03/10)
* [Лк. 12:33-34](rc://ru/tn/help/luk/12/33)
* [Мк. 14:47-50](rc://ru/tn/help/mrk/14/47)
* [Притч. 6:30-31](rc://ru/tn/help/pro/06/30)
* [Откр. 3:3-4](rc://ru/tn/help/rev/03/03)

## Данные о слове:

* Номера Стронга: H1214, H1215, H1416, H1589, H1590, H1980, H6530, H6782, H7703, G727, G1888, G2417, G2812, G3027
